@@ -7,7 +7,6 @@ from .FinError import FinError
 from numba import njit, boolean, int64
 import numpy as np
 
-
 ###############################################################################    
 
 from enum import Enum
@@ -103,7 +102,6 @@ gDateCounterList = None
 gStartYear = 1900
 gEndYear = 2100
 
-
 def calculateList():
     ''' Calculate list of dates so that we can do quick lookup to get the
     number of dates since 1 Jan 1900 (inclusive) BUT TAKING INTO ACCOUNT THE
@@ -114,6 +112,7 @@ def calculateList():
 
     dayCounter = 0
     maxDays = 0
+    
     global gDateCounterList
     global gStartYear
     global gEndYear
@@ -345,6 +344,45 @@ class FinDate():
 
     ###########################################################################
 
+    def isEOM(self):
+        ''' returns True if this date falls on a month end. '''
+        
+        y = self._y
+        m = self._m
+        d = self._d
+
+        leapYear = isLeapYear(y)
+
+        if leapYear:
+            if d == monthDaysLeapYear[m - 1]:
+                return True
+        else:
+            if d == monthDaysNotLeapYear[m - 1]:
+                return True
+                    
+        return False
+
+    ###########################################################################
+
+    def EOM(self):
+        ''' returns last date of month of this date. '''
+
+        y = self._y
+        m = self._m
+
+        leapYear = isLeapYear(y)
+
+        if leapYear:
+            lastDay = monthDaysLeapYear[m - 1]
+            return FinDate(lastDay, m, y)
+        else:
+            lastDay = monthDaysNotLeapYear[m - 1]
+            return FinDate(lastDay, m, y)
+
+        return False
+
+    ###########################################################################
+
     def addHours(self, hours):
         ''' Returns a new date that is h hours after the FinDate. '''
 
@@ -399,28 +437,25 @@ class FinDate():
         if isinstance(numDays, int) is False:
             raise FinError("Num days must be an integer")
 
-        dt = datetime.date(self._y, self._m, self._d)
-        d = dt.day
-        m = dt.month
-        y = dt.year
-        newDt = FinDate(d, m, y)
+        positiveNumDays = (numDays > 0)
+        numDays = abs(numDays)
+        
+        # 5 week days make up a week
+        numWeeks = int(numDays / 5)
+        remainingDays = numDays % 5
 
-        s = +1
-        if numDays < 0:
-            numDays = -1 * numDays
-            s = -1
+        if (positiveNumDays):
+            if (self._weekday + remainingDays > self.FRI):
+                # add weekend
+                remainingDays += 2
 
-        while numDays > 0:
-            dt = dt + s * datetime.timedelta(days=1)
-            d = dt.day
-            m = dt.month
-            y = dt.year
-            newDt = FinDate(d, m, y)
+            return self.addDays(numWeeks * 7 + remainingDays)
+        else:
+            if (self._weekday - remainingDays < self.MON):
+                # add weekend
+                remainingDays += 2
 
-            if newDt.isWeekend() is False:
-                numDays = numDays - 1
-
-        return newDt
+            return self.addDays(-(numWeeks * 7 + remainingDays))
 
     ###########################################################################
 
@@ -624,7 +659,7 @@ class FinDate():
     ###########################################################################
 
     def addTenor(self,
-                 tenor: str):
+                 tenor: (list,str)):
         ''' Return the date following the FinDate by a period given by the
         tenor which is a string consisting of a number and a letter, the
         letter being d, w, m , y for day, week, month or year. This is case
@@ -632,55 +667,73 @@ class FinDate():
         years. The date is NOT weekend or holiday calendar adjusted. This must
         be done AFTERWARDS. '''
 
-        if isinstance(tenor, str) is False:
-            raise FinError("Tenor must be a string e.g. '5Y'")
+        listFlag = False
 
-        tenor = tenor.upper()
-        DAYS = 1
-        WEEKS = 2
-        MONTHS = 3
-        YEARS = 4
-
-        periodType = 0
-        numPeriods = 0
-
-        if tenor == "ON":   # overnight - should be used only if spot days = 0
-            periodType = DAYS
-            numPeriods = 1
-        elif tenor == "TN":  # overnight - should be used when spot days > 0
-            periodType = DAYS
-            numPeriods = 1
-        elif tenor[-1] == "D":
-            periodType = DAYS
-            numPeriods = int(tenor[0:-1])
-        elif tenor[-1] == "W":
-            periodType = WEEKS
-            numPeriods = int(tenor[0:-1])
-        elif tenor[-1] == "M":
-            periodType = MONTHS
-            numPeriods = int(tenor[0:-1])
-        elif tenor[-1] == "Y":
-            periodType = YEARS
-            numPeriods = int(tenor[0:-1])
+        if isinstance(tenor, list) is True:
+            listFlag = True
+            for ten in tenor:
+                if isinstance(ten, str) is False:
+                    raise FinError("Tenor must be a string e.g. '5Y'")
         else:
-            raise FinError("Unknown tenor type in " + tenor)
+            if isinstance(tenor, str) is True:
+                tenor = [tenor]
+            else:
+                raise FinError("Tenor must be a string e.g. '5Y'")
 
-        newDate = FinDate(self._d, self._m, self._y)
+        newDates = []
 
-        if periodType == DAYS:
-            for _ in range(0, numPeriods):
-                newDate = newDate.addDays(1)
-        elif periodType == WEEKS:
-            for _ in range(0, numPeriods):
-                newDate = newDate.addDays(7)
-        elif periodType == MONTHS:
-            for _ in range(0, numPeriods):
-                newDate = newDate.addMonths(1)
-        elif periodType == YEARS:
-            for _ in range(0, numPeriods):
-                newDate = newDate.addMonths(12)
+        for tenStr in tenor:            
+            tenStr = tenStr.upper()
+            DAYS = 1
+            WEEKS = 2
+            MONTHS = 3
+            YEARS = 4
+    
+            periodType = 0
+            numPeriods = 0
+    
+            if tenStr == "ON":   # overnight - should be used only if spot days = 0
+                periodType = DAYS
+                numPeriods = 1
+            elif tenStr == "TN":  # overnight - should be used when spot days > 0
+                periodType = DAYS
+                numPeriods = 1
+            elif tenStr[-1] == "D":
+                periodType = DAYS
+                numPeriods = int(tenStr[0:-1])
+            elif tenStr[-1] == "W":
+                periodType = WEEKS
+                numPeriods = int(tenStr[0:-1])
+            elif tenStr[-1] == "M":
+                periodType = MONTHS
+                numPeriods = int(tenStr[0:-1])
+            elif tenStr[-1] == "Y":
+                periodType = YEARS
+                numPeriods = int(tenStr[0:-1])
+            else:
+                raise FinError("Unknown tenor type in " + tenor)
+    
+            newDate = FinDate(self._d, self._m, self._y)
+    
+            if periodType == DAYS:
+                for _ in range(0, numPeriods):
+                    newDate = newDate.addDays(1)
+            elif periodType == WEEKS:
+                for _ in range(0, numPeriods):
+                    newDate = newDate.addDays(7)
+            elif periodType == MONTHS:
+                for _ in range(0, numPeriods):
+                    newDate = newDate.addMonths(1)
+            elif periodType == YEARS:
+                for _ in range(0, numPeriods):
+                    newDate = newDate.addMonths(12)
 
-        return newDate
+            newDates.append(newDate)
+
+        if listFlag is True:
+            return newDates
+        else:
+            return newDates[0]
 
     ###########################################################################
 
@@ -729,7 +782,6 @@ class FinDate():
         shortYearStr = str(self._y)[2:]
         longYearStr = str(self._y)
 
-        
         if gDateFormatType == FinDateFormatTypes.UK_LONGEST:
 
             sep = " "
