@@ -8,6 +8,12 @@ from enum import Enum
 
 ###############################################################################
 
+class FinLongShort(Enum):
+    LONG = 1
+    SHORT = 2
+
+###############################################################################
+
 class FinOptionTypes(Enum):
     EUROPEAN_CALL = 1
     EUROPEAN_PUT = 2
@@ -40,3 +46,8 @@ class FinExerciseTypes(Enum):
     AMERICAN = 3
 
 ###############################################################################
+
+class FinSolverTypes(Enum):
+    CONJUGATE_GRADIENT = 0
+    NELDER_MEAD = 1
+    NELDER_MEAD_NUMBA = 2
