@@ -24,11 +24,11 @@ from ...products.credit.FinCDSCurve import FinCDSCurve
 
 from ...finutils.FinGlobalVariables import gDaysInYear
 from ...finutils.FinMath import ONE_MILLION
-from ...market.curves.FinInterpolate import interpolate, FinInterpTypes
+from ...market.curves.FinInterpolator import interpolate, FinInterpTypes
 
 from ...finutils.FinHelperFunctions import checkArgumentTypes
 from ...finutils.FinDate import FinDate
-from ...finutils.FinHelperFunctions import labelToString, tableToString
+from ...finutils.FinHelperFunctions import labelToString
 
 ###############################################################################
 # TODO: Convert functions to use NUMBA!!
@@ -45,7 +45,7 @@ class FinCDSBasket(object):
                  notional: float = ONE_MILLION,
                  runningCoupon: float = 0.0,
                  longProtection: bool = True,
-                 frequencyType: FinFrequencyTypes = FinFrequencyTypes.QUARTERLY,
+                 freqType: FinFrequencyTypes = FinFrequencyTypes.QUARTERLY,
                  dayCountType: FinDayCountTypes = FinDayCountTypes.ACT_360,
                  calendarType: FinCalendarTypes = FinCalendarTypes.WEEKEND,
                  busDayAdjustType: FinBusDayAdjustTypes = FinBusDayAdjustTypes.FOLLOWING,
@@ -61,7 +61,7 @@ class FinCDSBasket(object):
         self._dayCountType = dayCountType
         self._dateGenRuleType = dateGenRuleType
         self._calendarType = calendarType
-        self._frequencyType = frequencyType
+        self._freqType = freqType
         self._busDayAdjustType = busDayAdjustType
 
         self._cdsContract = FinCDS(self._stepInDate,
@@ -69,7 +69,7 @@ class FinCDSBasket(object):
                                    self._runningCoupon,
                                    1.0,
                                    self._longProtection,
-                                   self._frequencyType,
+                                   self._freqType,
                                    self._dayCountType,
                                    self._calendarType,
                                    self._busDayAdjustType,
@@ -275,7 +275,7 @@ class FinCDSBasket(object):
                 recoveryRates[iCredit] = issuerCurve._recoveryRate
                 issuerSurvivalProbabilities[iCredit] = interpolate(
                     t, issuerCurve._times, issuerCurve._values,
-                    FinInterpTypes.FLAT_FORWARDS.value)
+                    FinInterpTypes.FLAT_FWD_RATES.value)
 
             lossDbn = homogeneousBasketLossDbn(issuerSurvivalProbabilities,
                                                recoveryRates,
@@ -323,7 +323,7 @@ class FinCDSBasket(object):
         s += labelToString("NOTIONAL", self._notional)
         s += labelToString("RUNNING COUPON", self._runningCoupon*10000, "bp\n")
         s += labelToString("DAYCOUNT", self._dayCountType)
-        s += labelToString("FREQUENCY", self._frequencyType)
+        s += labelToString("FREQUENCY", self._freqType)
         s += labelToString("CALENDAR", self._calendarType)
         s += labelToString("BUSDAYRULE", self._busDayAdjustType)
         s += labelToString("DATEGENRULE", self._dateGenRuleType)
