@@ -8,6 +8,7 @@ from scipy import optimize
 
 from ...finutils.FinMath import M
 from ...finutils.FinGlobalVariables import gDaysInYear
+from ...finutils.FinGlobalVariables import gSmall
 from ...finutils.FinError import FinError
 
 from ...products.equity.FinEquityOption import FinEquityOption
@@ -88,7 +89,7 @@ class FinEquityChooserOption(FinEquityOption):
               valueDate: FinDate,
               stockPrice: float,
               discountCurve: FinDiscountCurve,
-              dividendYield: float,
+              dividendCurve: FinDiscountCurve,
               model):
         ''' Value the complex chooser option using an approach by Rubinstein
         (1991). See also Haug page 129 for complex chooser options. '''
@@ -102,23 +103,20 @@ class FinEquityChooserOption(FinEquityOption):
         tc = (self._callExpiryDate - valueDate) / gDaysInYear
         tp = (self._putExpiryDate - valueDate) / gDaysInYear
 
-        dft = discountCurve.df(self._chooseDate)
-        dftc = discountCurve.df(self._callExpiryDate)
-        dftp = discountCurve.df(self._putExpiryDate)
+        rt = discountCurve.ccRate(self._chooseDate)
+        rtc = discountCurve.ccRate(self._callExpiryDate)
+        rtp = discountCurve.ccRate(self._putExpiryDate)
 
-        rt = -np.log(dft) / t
-        rtc = -np.log(dftc) / tc
-        rtp = -np.log(dftp) / tp
+        q = dividendCurve.ccRate(self._chooseDate)
 
-        t = max(t, 1e-6)
-        tc = max(tc, 1e-6)
-        tp = max(tp, 1e-6)
+        t = max(t, gSmall)
+        tc = max(tc, gSmall)
+        tp = max(tp, gSmall)
 
         v = model._volatility
-        v = max(v, 1e-6)
+        v = max(v, gSmall)
 
         s0 = stockPrice
-        q = dividendYield
         xc = self._callStrike
         xp = self._putStrike
         bt = rt - q
@@ -168,7 +166,7 @@ class FinEquityChooserOption(FinEquityOption):
                 valueDate: FinDate,
                 stockPrice: float,
                 discountCurve: FinDiscountCurve,
-                dividendYield: float,
+                dividendCurve: FinDiscountCurve,
                 model,
                 numPaths: int = 10000,
                 seed: int = 4242):
@@ -193,7 +191,11 @@ class FinEquityChooserOption(FinEquityOption):
         v = model._volatility
         v = max(v, 1e-6)
 
-        q = dividendYield
+        # SHOULD THIS CARE ABOUT TERM STRUCTURE OF Q
+        dq = dividendCurve.df(self._chooseDate)
+        q = -np.log(dq) / t
+
+#        q = dividendYield
         kc = self._callStrike
         kp = self._putStrike
 
@@ -208,11 +210,11 @@ class FinEquityChooserOption(FinEquityOption):
         s_1 = s * m
         s_2 = s / m
 
-        v_call_1 = bsValue(s_1, tc-t, kc, rtc, q, v, +1.0)
-        v_put_1 = bsValue(s_1, tp-t, kp, rtp, q, v, -1.0)
+        v_call_1 = bsValue(s_1, tc-t, kc, rtc, q, v, FinOptionTypes.EUROPEAN_CALL.value)
+        v_put_1 = bsValue(s_1, tp-t, kp, rtp, q, v, FinOptionTypes.EUROPEAN_PUT.value)
 
-        v_call_2 = bsValue(s_2, tc-t, kc, rtc, q, v, +1.0)
-        v_put_2 = bsValue(s_2, tp-t, kp, rtp, q, v, -1.0)
+        v_call_2 = bsValue(s_2, tc-t, kc, rtc, q, v, FinOptionTypes.EUROPEAN_CALL.value)
+        v_put_2 = bsValue(s_2, tp-t, kp, rtp, q, v, FinOptionTypes.EUROPEAN_PUT.value)
 
         payoff_1 = np.maximum(v_call_1, v_put_1)
         payoff_2 = np.maximum(v_call_2, v_put_2)
