@@ -15,7 +15,7 @@ from ...finutils.FinHelperFunctions import labelToString, checkArgumentTypes
 from ...finutils.FinDate import FinDate
 from ...market.curves.FinDiscountCurve import FinDiscountCurve
 
-from ...finutils.FinMath import N
+from ...finutils.FinMath import NVect
 
 
 ###############################################################################
@@ -62,7 +62,7 @@ class FinEquityDigitalOption(FinEquityOption):
               valueDate: FinDate,
               stockPrice: (float, np.ndarray),
               discountCurve: FinDiscountCurve,
-              dividendYield: float,
+              dividendCurve: FinDiscountCurve,
               model):
         ''' Digital Option valuation using the Black-Scholes model assuming a
         barrier at expiry. Handles both cash-or-nothing and asset-or-nothing
@@ -79,11 +79,13 @@ class FinEquityDigitalOption(FinEquityOption):
         lnS0k = np.log(S0 / X)
 
         sqrtT = np.sqrt(t)
-        q = dividendYield
 
         df = discountCurve.df(self._expiryDate)
         r = -np.log(df)/t
 
+        dq = dividendCurve.df(self._expiryDate)
+        q = -np.log(dq)/t
+
         volatility = model._volatility
 
         if abs(volatility) < gSmall:
@@ -95,14 +97,14 @@ class FinEquityDigitalOption(FinEquityOption):
 
         if self._underlyingType == FinDigitalOptionTypes.CASH_OR_NOTHING:
             if self._optionType == FinOptionTypes.EUROPEAN_CALL:
-                v = np.exp(-r * t) * N(d2)
+                v = np.exp(-r * t) * NVect(d2)
             elif self._optionType == FinOptionTypes.EUROPEAN_PUT:
-                v = np.exp(-r * t) * N(-d2)
+                v = np.exp(-r * t) * NVect(-d2)
         elif self._underlyingType == FinDigitalOptionTypes.ASSET_OR_NOTHING:
             if self._optionType == FinOptionTypes.EUROPEAN_CALL:
-                v = S0 * np.exp(-q * t) * N(d1)
+                v = S0 * np.exp(-q * t) * NVect(d1)
             elif self._optionType == FinOptionTypes.EUROPEAN_PUT:
-                v = S0 * np.exp(-q * t) * N(-d1)
+                v = S0 * np.exp(-q * t) * NVect(-d1)
         else:
             raise FinError("Unknown underlying type.")
 
@@ -114,7 +116,7 @@ class FinEquityDigitalOption(FinEquityOption):
                 valueDate: FinDate,
                 stockPrice: float,
                 discountCurve: FinDiscountCurve,
-                dividendYield: float,
+                dividendCurve: FinDiscountCurve,
                 model,
                 numPaths: int = 10000,
                 seed: int = 4242):
@@ -127,8 +129,10 @@ class FinEquityDigitalOption(FinEquityOption):
         df = discountCurve.df(self._expiryDate)
         r = -np.log(df)/t
 
+        dq = dividendCurve.df(self._expiryDate)
+        q = -np.log(dq)/t
+
         volatility = model._volatility
-        q = dividendYield
         K = self._barrierPrice
         sqrtdt = np.sqrt(t)
 
