@@ -11,9 +11,9 @@ sys.path.append("..")
 from financepy.finutils.FinGlobalTypes import FinSwapTypes
 from financepy.products.bonds.FinBond import FinYTMCalcType
 from financepy.products.bonds.FinBond import FinBond
-from financepy.products.funding.FinIborSingleCurve import FinIborSingleCurve
-from financepy.products.funding.FinIborDeposit import FinIborDeposit
-from financepy.products.funding.FinIborSwap import FinIborSwap
+from financepy.products.rates.FinIborSingleCurve import FinIborSingleCurve
+from financepy.products.rates.FinIborDeposit import FinIborDeposit
+from financepy.products.rates.FinIborSwap import FinIborSwap
 from financepy.finutils.FinMath import ONE_MILLION
 from financepy.finutils.FinDate import FinDate, fromDatetime
 from financepy.finutils.FinDayCount import FinDayCountTypes
@@ -24,9 +24,10 @@ from financepy.market.curves.FinDiscountCurveFlat import FinDiscountCurveFlat
 from FinTestCases import FinTestCases, globalTestCaseMode
 testCases = FinTestCases(__file__, globalTestCaseMode)
 
-##########################################################################
 
 
+##########################################################################
+
 def buildIborCurve(valuationDate):
 
     depoDCCType = FinDayCountTypes.THIRTY_E_360_ISDA
@@ -98,6 +99,9 @@ def buildIborCurve(valuationDate):
         swapRate,
         fixedFreqType,
         fixedDCCType)
+    
+#    print(swap1._fixedLeg._paymentDates)
+
     swaps.append(swap1)
 
     maturityDate = settlementDate.addMonths(36)
@@ -110,6 +114,9 @@ def buildIborCurve(valuationDate):
         fixedDCCType)
     swaps.append(swap2)
 
+#    print(swap2._fixedLeg._paymentDates)
+
+    
     maturityDate = settlementDate.addMonths(48)
     swap3 = FinIborSwap(
         settlementDate,
@@ -120,6 +127,8 @@ def buildIborCurve(valuationDate):
         fixedDCCType)
     swaps.append(swap3)
 
+#    print(swap3._fixedLeg._paymentDates)
+
     maturityDate = settlementDate.addMonths(60)
     swap4 = FinIborSwap(
         settlementDate,
@@ -130,6 +139,8 @@ def buildIborCurve(valuationDate):
         fixedDCCType)
     swaps.append(swap4)
 
+#    print(swap4._fixedLeg._paymentDates)
+
     maturityDate = settlementDate.addMonths(72)
     swap5 = FinIborSwap(
         settlementDate,
@@ -140,6 +151,8 @@ def buildIborCurve(valuationDate):
         fixedDCCType)
     swaps.append(swap5)
 
+#    print(swap5._fixedLeg._paymentDates)
+
     maturityDate = settlementDate.addMonths(84)
     swap6 = FinIborSwap(
         settlementDate,
@@ -150,6 +163,8 @@ def buildIborCurve(valuationDate):
         fixedDCCType)
     swaps.append(swap6)
 
+#    print(swap6._fixedLeg._paymentDates)
+
     maturityDate = settlementDate.addMonths(96)
     swap7 = FinIborSwap(
         settlementDate,
@@ -160,6 +175,8 @@ def buildIborCurve(valuationDate):
         fixedDCCType)
     swaps.append(swap7)
 
+#    print(swap7._fixedLeg._paymentDates)
+
     maturityDate = settlementDate.addMonths(108)
     swap8 = FinIborSwap(
         settlementDate,
@@ -170,6 +187,8 @@ def buildIborCurve(valuationDate):
         fixedDCCType)
     swaps.append(swap8)
 
+#    print(swap8._fixedLeg._paymentDates)
+
     maturityDate = settlementDate.addMonths(120)
     swap9 = FinIborSwap(
         settlementDate,
@@ -180,6 +199,8 @@ def buildIborCurve(valuationDate):
         fixedDCCType)
     swaps.append(swap9)
 
+#    print(swap9._fixedLeg._paymentDates)
+
     liborCurve = FinIborSingleCurve(valuationDate,
                                     depos,
                                     fras,
@@ -239,6 +260,7 @@ def test_FinBond():
                             "%10.4f" % cleanPrice, "%6.0f" % accd_days,
                             "%10.4f" % accd, "%8.4f" % ytm)
 
+    ###########################################################################
     #  EXAMPLE FROM http://bondtutor.com/btchp4/topic6/topic6.htm
 
     accrualConvention = FinDayCountTypes.ACT_ACT_ICMA
@@ -459,7 +481,7 @@ def test_FinBondExDividend():
     exDivDays = 7
     testCases.header("LABEL", "VALUE")
 
-    calendarType = FinCalendarTypes.UK
+    calendarType = FinCalendarTypes.UNITED_KINGDOM
     bond = FinBond(issueDate, maturityDate, coupon,
                    freqType, accrualType, face)
     settlementDate = FinDate(7, 9, 2003)
@@ -479,7 +501,7 @@ def test_FinBondExDividend():
     face = 100.0
     exDivDays = 7
 
-    calendarType = FinCalendarTypes.UK
+    calendarType = FinCalendarTypes.UNITED_KINGDOM
     bond = FinBond(issueDate, maturityDate, coupon,
                    freqType, accrualType, face)
 
