@@ -6,13 +6,15 @@ import sys
 sys.path.append("..")
 
 from financepy.finutils.FinDate import FinDate
+
 from financepy.products.bonds.FinBondMortgage import FinBondMortgage
 from financepy.products.bonds.FinBondMortgage import FinBondMortgageTypes
-from financepy.products.funding.FinIborSingleCurve import FinIborSingleCurve
+from financepy.products.rates.FinIborSingleCurve import FinIborSingleCurve
 
 from FinTestCases import FinTestCases, globalTestCaseMode
 testCases = FinTestCases(__file__, globalTestCaseMode)
 
+
 ###############################################################################
 
 
@@ -49,6 +51,8 @@ def test_FinBondMortgage():
                         mortgage._principalFlows[i],
                         mortgage._principalRemaining[i],
                         mortgage._totalFlows[i])
+
+
 ###############################################################################
 
 
