@@ -11,10 +11,10 @@ sys.path.append("..")
 from financepy.products.credit.FinCDS import FinCDS
 from financepy.finutils.FinMath import ONE_MILLION
 from financepy.market.curves.FinInterpolator import FinInterpTypes
-from financepy.products.funding.FinIborSwap import FinIborSwap
-from financepy.products.funding.FinIborDeposit import FinIborDeposit
+from financepy.products.rates.FinIborSwap import FinIborSwap
+from financepy.products.rates.FinIborDeposit import FinIborDeposit
 from financepy.market.curves.FinDiscountCurve import FinDiscountCurve
-from financepy.products.funding.FinIborSingleCurve import FinIborSingleCurve
+from financepy.products.rates.FinIborSingleCurve import FinIborSingleCurve
 from financepy.products.credit.FinCDSCurve import FinCDSCurve
 from financepy.finutils.FinGlobalVariables import gDaysInYear
 from financepy.finutils.FinCalendar import FinBusDayAdjustTypes
