@@ -12,8 +12,8 @@ from financepy.products.credit.FinCDSTranche import FinLossDistributionBuilder
 from financepy.products.credit.FinCDSIndexPortfolio import FinCDSIndexPortfolio
 from financepy.products.credit.FinCDSTranche import FinCDSTranche
 from financepy.products.credit.FinCDS import FinCDS
-from financepy.products.funding.FinIborSwap import FinIborSwap
-from financepy.products.funding.FinIborSingleCurve import FinIborSingleCurve
+from financepy.products.rates.FinIborSwap import FinIborSwap
+from financepy.products.rates.FinIborSingleCurve import FinIborSingleCurve
 from financepy.products.credit.FinCDSCurve import FinCDSCurve
 from financepy.finutils.FinFrequency import FinFrequencyTypes
 from financepy.finutils.FinDayCount import FinDayCountTypes
