@@ -2,21 +2,24 @@
 # Copyright (C) 2018, 2019, 2020 Dominic O'Kane
 ###############################################################################
 
-from FinTestCases import FinTestCases, globalTestCaseMode
+import sys
+sys.path.append("..")
 
 from financepy.finutils.FinDate import FinDate
 from financepy.finutils.FinDayCount import FinDayCount, FinDayCountTypes
-import sys
-sys.path.append("..//..")
-
+from financepy.finutils.FinFrequency import FinFrequencyTypes
 
+from FinTestCases import FinTestCases, globalTestCaseMode
 testCases = FinTestCases(__file__, globalTestCaseMode)
 
+##############################################################################
 
 def test_FinDayCount():
 
     testCases.header("DAY_COUNT_METHOD", "START", "END", "ALPHA")
 
+    finFreq = FinFrequencyTypes.ANNUAL
+
     for dayCountMethod in FinDayCountTypes:
 
         startDate = FinDate(2019, 1, 1)
@@ -26,7 +29,7 @@ def test_FinDayCount():
 
         for _ in range(0, numDays):
             nextDate = nextDate.addDays(7)
-            dcf = dayCount.yearFrac(startDate, nextDate, nextDate, 1)
+            dcf = dayCount.yearFrac(startDate, nextDate, nextDate, finFreq)
 
             testCases.print(
                 str(dayCountMethod),
