@@ -7,11 +7,14 @@ import time
 import sys
 sys.path.append("..")
 
+import numpy as np
+
 from financepy.finutils.FinGlobalTypes import FinOptionTypes
 from financepy.products.equity.FinEquityVanillaOption import FinEquityVanillaOption
 from financepy.market.curves.FinDiscountCurveFlat import FinDiscountCurveFlat
 from financepy.models.FinModelBlackScholes import FinModelBlackScholes
 from financepy.finutils.FinDate import FinDate
+from financepy.finutils.FinError import FinError
 
 from FinTestCases import FinTestCases, globalTestCaseMode
 testCases = FinTestCases(__file__, globalTestCaseMode)
@@ -29,6 +32,7 @@ def test_FinEquityVanillaOption():
     dividendYield = 0.01
     model = FinModelBlackScholes(volatility)
     discountCurve = FinDiscountCurveFlat(valueDate, interestRate)
+    dividendCurve = FinDiscountCurveFlat(valueDate, dividendYield)
 
     numPathsList = [10000, 20000, 40000, 80000, 160000, 320000]
 
@@ -39,10 +43,10 @@ def test_FinEquityVanillaOption():
         callOption = FinEquityVanillaOption(
             expiryDate, 100.0, FinOptionTypes.EUROPEAN_CALL)
         value = callOption.value(valueDate, stockPrice, discountCurve,
-                                 dividendYield, model)
+                                 dividendCurve, model)
         start = time.time()
         valueMC = callOption.valueMC(valueDate, stockPrice, discountCurve,
-                                     dividendYield, model, numPaths)
+                                     dividendCurve, model, numPaths)
         end = time.time()
         duration = end - start
         testCases.print(numPaths, value, valueMC, duration)
@@ -62,17 +66,17 @@ def test_FinEquityVanillaOption():
                                             FinOptionTypes.EUROPEAN_CALL)
 
         value = callOption.value(valueDate, stockPrice, discountCurve,
-                                 dividendYield, model)
+                                 dividendCurve, model)
 
         start = time.time()
 
         useSobol = False
         valueMC1 = callOption.valueMC(valueDate, stockPrice, discountCurve,
-                                      dividendYield, model, numPaths, useSobol)
+                                      dividendCurve, model, numPaths, useSobol)
 
         useSobol = True
         valueMC2 = callOption.valueMC(valueDate, stockPrice, discountCurve,
-                                      dividendYield, model, numPaths, useSobol)
+                                      dividendCurve, model, numPaths, useSobol)
 
         end = time.time()
         duration = end - start
@@ -92,17 +96,17 @@ def test_FinEquityVanillaOption():
                                            FinOptionTypes.EUROPEAN_PUT)
 
         value = putOption.value(valueDate, stockPrice, discountCurve,
-                                dividendYield, model)
+                                dividendCurve, model)
 
         start = time.time()
 
         useSobol = False
         valueMC1 = putOption.valueMC(valueDate, stockPrice, discountCurve,
-                                      dividendYield, model, numPaths, useSobol)
+                                      dividendCurve, model, numPaths, useSobol)
 
         useSobol = True
         valueMC2 = putOption.valueMC(valueDate, stockPrice, discountCurve,
-                                      dividendYield, model, numPaths, useSobol)
+                                      dividendCurve, model, numPaths, useSobol)
 
         end = time.time()
         duration = end - start
@@ -120,15 +124,15 @@ def test_FinEquityVanillaOption():
         callOption = FinEquityVanillaOption(expiryDate, 100.0, 
                                             FinOptionTypes.EUROPEAN_CALL)
         value = callOption.value(valueDate, stockPrice, discountCurve,
-                                 dividendYield, model)
+                                 dividendCurve, model)
         delta = callOption.delta(valueDate, stockPrice, discountCurve,
-                                 dividendYield, model)
+                                 dividendCurve, model)
         vega = callOption.vega(valueDate, stockPrice, discountCurve,
-                                 dividendYield, model)
+                                 dividendCurve, model)
         theta = callOption.theta(valueDate, stockPrice, discountCurve,
-                                 dividendYield, model)
+                                 dividendCurve, model)
         rho = callOption.rho(valueDate, stockPrice, discountCurve,
-                                 dividendYield, model)
+                                 dividendCurve, model)
         testCases.print(stockPrice, value, delta, vega, theta, rho)
 
     ###########################################################################
@@ -142,38 +146,109 @@ def test_FinEquityVanillaOption():
                                            FinOptionTypes.EUROPEAN_PUT)
 
         value = putOption.value(valueDate, stockPrice, discountCurve,
-                                 dividendYield, model)
+                                 dividendCurve, model)
         delta = putOption.delta(valueDate, stockPrice, discountCurve,
-                                 dividendYield, model)
+                                 dividendCurve, model)
         vega = putOption.vega(valueDate, stockPrice, discountCurve,
-                                 dividendYield, model)
+                                 dividendCurve, model)
         theta = putOption.theta(valueDate, stockPrice, discountCurve,
-                                 dividendYield, model)
+                                 dividendCurve, model)
         rho = putOption.rho(valueDate, stockPrice, discountCurve,
-                                 dividendYield, model)
+                                 dividendCurve, model)
         testCases.print(stockPrice, value, delta, vega, theta, rho)
 
-###############################################################################
 
-    testCases.header("STOCK PRICE", "VALUE_BS", "VOL_IN", "IMPLD_VOL")
+def testImpliedVolatility_NEW():
 
-    stockPrices = range(60, 150, 10)
 
-    for stockPrice in stockPrices:
-        callOption = FinEquityVanillaOption(
-            expiryDate, 100.0, FinOptionTypes.EUROPEAN_CALL)
-        value = callOption.value(
-            valueDate,
-            stockPrice,
-            discountCurve,
-            dividendYield,
-            model)
-        impliedVol = callOption.impliedVolatility(
-            valueDate, stockPrice, discountCurve, dividendYield, value)
-        testCases.print(stockPrice, value, volatility, impliedVol)
+    valueDate = FinDate(1, 1, 2015)
+    stockPrice = 100.0
+    interestRate = 0.05
+    dividendYield = 0.03
+    discountCurve = FinDiscountCurveFlat(valueDate, interestRate)
+    dividendCurve = FinDiscountCurveFlat(valueDate, dividendYield)
+
+    strikes = np.linspace(50, 150, 11)
+    timesToExpiry = [0.003, 0.01, 0.1, 0.5, 1.0, 2.0, 5.0]    
+    sigmas = np.arange(1, 100, 5) / 100.0
+    optionTypes = [FinOptionTypes.EUROPEAN_CALL, FinOptionTypes.EUROPEAN_PUT]
+
+    testCases.header("OPT_TYPE", "TEXP", "STOCK_PRICE", "STRIKE", "INTRINSIC",
+                     "VALUE", "INPUT_VOL", "IMPLIED_VOL")
+    
+    tol = 1e-5
+    numTests = 0
+    numFails = 0
+    
+    for vol in sigmas:
+
+        model = FinModelBlackScholes(vol)
+
+        for timeToExpiry in timesToExpiry:     
+
+            expiryDate = valueDate.addYears(timeToExpiry)
+
+            for strike in strikes:
+
+                for optionType in optionTypes:
+
+                    option = FinEquityVanillaOption(expiryDate, strike, 
+                                                    optionType)
+                
+                    value = option.value(valueDate, stockPrice, discountCurve, 
+                                         dividendCurve, model)
+
+                    intrinsic = option.intrinsic(valueDate, stockPrice,
+                                             discountCurve, dividendCurve)
+
+                    # I remove the cases where the time value is zero
+                    # This is arbitrary but 1e-10 seems good enough to me
+                    
+                    impliedVol = -999
+
+                    if value - intrinsic > 1e-10:
+
+                        impliedVol = option.impliedVolatility(valueDate, 
+                                                              stockPrice, 
+                                                              discountCurve, 
+                                                              dividendCurve, 
+                                                              value)
+    
+                    numTests += 1    
+                        
+                    errVol = np.abs(impliedVol - vol)
+    
+                    if errVol > tol:
+    
+                        testCases.print(optionType, 
+                                  timeToExpiry, 
+                                  stockPrice,
+                                  strike, 
+                                  intrinsic,
+                                  value, 
+                                  vol, 
+                                  impliedVol)
+
+                        # These fails include ones due to the zero time value    
+                        numFails += 1
+                            
+                        testCases.print(optionType, timeToExpiry, stockPrice,
+                                        strike,
+                                        stockPrice, value, vol, impliedVol)
+
+    assert numFails == 694, "Num Fails has changed."
+
+#    print("Num Tests", numTests, "numFails", numFails)
 
 ###############################################################################
 
-
 test_FinEquityVanillaOption()
+
+start = time.time()
+testImpliedVolatility_NEW()
+end = time.time()
+elapsed = end - start
+
+#print("Elapsed:", elapsed)
+
 testCases.compareTestCases()
