@@ -10,10 +10,13 @@ from financepy.market.volatility.FinFXVolSurface import FinFXVolSurface
 from financepy.market.volatility.FinFXVolSurface import FinFXATMMethod
 from financepy.market.volatility.FinFXVolSurface import FinFXDeltaMethod
 from financepy.finutils.FinDate import FinDate
+from financepy.models.FinModelVolatilityFns import FinVolFunctionTypes
 
 from FinTestCases import FinTestCases, globalTestCaseMode
 testCases = FinTestCases(__file__, globalTestCaseMode)
 
+import matplotlib.pyplot as plt
+
 ###############################################################################
 
 PLOT_GRAPHS = False
@@ -21,14 +24,14 @@ PLOT_GRAPHS = False
 ###############################################################################
 
 
-def test_FinFXMktVolSurface1():
+def test_FinFXMktVolSurface1(verboseCalibration):
 
     ###########################################################################
 
     if 1 == 1:
 
         # Example from Book extract by Iain Clarke using Tables 3.3 and 3.4
-        # print("EURUSD EXAMPLE CLARKE")
+        # print("EURUSD EXAMPLE CLARK")
 
         valueDate = FinDate(10, 4, 2020)
 
@@ -52,6 +55,7 @@ def test_FinFXMktVolSurface1():
 
         atmMethod = FinFXATMMethod.FWD_DELTA_NEUTRAL
         deltaMethod = FinFXDeltaMethod.SPOT_DELTA
+        volFunctionType = FinVolFunctionTypes.CLARK
 
         fxMarket = FinFXVolSurface(valueDate,
                                    spotFXRate,
@@ -64,21 +68,51 @@ def test_FinFXMktVolSurface1():
                                    marketStrangle25DeltaVols,
                                    riskReversal25DeltaVols,
                                    atmMethod,
-                                   deltaMethod)
+                                   deltaMethod, 
+                                   volFunctionType)
 
-        fxMarket.checkCalibration(False)
+        fxMarket.checkCalibration(verboseCalibration)
+
+        # EXPLORE AND TEST DIFFERENT CATEGORICAL PARAMETERS
+        # for atmMethod in FinFXATMMethod:
+        #     for deltaMethod in FinFXDeltaMethod:
+        #         for volFunctionType in FinVolFunctionTypes:
+    
+        #             fxMarket = FinFXVolSurface(valueDate,
+        #                                        spotFXRate,
+        #                                        currencyPair,
+        #                                        notionalCurrency,
+        #                                        domDiscountCurve,
+        #                                        forDiscountCurve,
+        #                                        tenors,
+        #                                        atmVols,
+        #                                        marketStrangle25DeltaVols,
+        #                                        riskReversal25DeltaVols,
+        #                                        atmMethod,
+        #                                        deltaMethod, 
+        #                                        volFunctionType)
+        
+        #             fxMarket.checkCalibration(verboseCalibration)
 
         if PLOT_GRAPHS:
+
             fxMarket.plotVolCurves()
 
+            dbns = fxMarket.impliedDbns(0.00001, 5.0, 10000)
+
+            for i in range(0, len(dbns)):
+                plt.plot(dbns[i]._x, dbns[i]._densitydx)
+                plt.title(volFunctionType)
+                print("SUM:", dbns[i].sum())
+
     ###########################################################################
 
-def test_FinFXMktVolSurface2():
+def test_FinFXMktVolSurface2(verboseCalibration):
 
         #print("==============================================================")
 
-        # Example from Book extract by Iain Clarke using Tables 3.3 and 3.4
-        #print("EURJPY EXAMPLE CLARKE")
+        # Example from Book extract by Iain Clark using Tables 3.3 and 3.4
+        # print("EURJPY EXAMPLE CLARK")
 
         valueDate = FinDate(10, 4, 2020)
 
@@ -94,9 +128,9 @@ def test_FinFXMktVolSurface2():
         spotFXRate = 90.72
 
         tenors = ['1M', '2M', '3M', '6M', '1Y', '2Y']
-        atmVols = [21.50, 21.00, 19.85, 18.00, 15.95, 14.009]
-        marketStrangle25DeltaVols = [0.35, 0.325, 0.30, 0.225, 0.175, 0.10]
-        riskReversal25DeltaVols = [-8.35, -8.65, -8.95, -9.25, -9.550, -9.500]
+        atmVols = [21.50, 20.50, 19.85, 18.00, 15.95, 14.009]
+        marketStrangle25DeltaVols = [0.35, 0.325, 0.300, 0.225, 0.175, 0.100]
+        riskReversal25DeltaVols = [-8.350, -8.650, -8.950, -9.250, -9.550, -9.500]
 
         notionalCurrency = forName
 
@@ -116,16 +150,16 @@ def test_FinFXMktVolSurface2():
                                    atmMethod,
                                    deltaMethod)
 
-        fxMarket.checkCalibration(False)
+        fxMarket.checkCalibration(verboseCalibration)
 
         if PLOT_GRAPHS:
             fxMarket.plotVolCurves()
 
-#    print("==================================================================")
+#   print("==================================================================")
 
-#    ###########################################################################
+#   ###########################################################################
 
-def test_FinFXMktVolSurface3():
+def test_FinFXMktVolSurface3(verboseCalibration):
 
         # EURUSD Example from Paper by Uwe Wystup using Tables 4
 #        print("EURUSD EXAMPLE WYSTUP")
@@ -166,14 +200,14 @@ def test_FinFXMktVolSurface3():
                                    atmMethod,
                                    deltaMethod)
 
-        fxMarket.checkCalibration(False)
+        fxMarket.checkCalibration(verboseCalibration)
 
         if PLOT_GRAPHS:
             fxMarket.plotVolCurves()
 
     ###########################################################################
 
-def test_FinFXMktVolSurface4():
+def test_FinFXMktVolSurface4(verboseCalibration):
 
         # USDJPY Example from Paper by Uwe Wystup using Tables 4
 #        print("USDJPY EXAMPLE WYSTUP")
@@ -214,7 +248,7 @@ def test_FinFXMktVolSurface4():
                                    atmMethod,
                                    deltaMethod)
 
-        fxMarket.checkCalibration(False)
+        fxMarket.checkCalibration(verboseCalibration)
 
         if PLOT_GRAPHS:
             fxMarket.plotVolCurves()
@@ -224,10 +258,21 @@ def test_FinFXMktVolSurface4():
 
 ###############################################################################
 
+import time
 
-test_FinFXMktVolSurface1()
-test_FinFXMktVolSurface2()
-test_FinFXMktVolSurface3()
-test_FinFXMktVolSurface4()
+if __name__ == '__main__':
 
-testCases.compareTestCases()
+    start = time.time()
+
+    verboseCalibration = False
+
+    test_FinFXMktVolSurface1(verboseCalibration)
+    test_FinFXMktVolSurface2(verboseCalibration)
+    test_FinFXMktVolSurface3(verboseCalibration)
+    test_FinFXMktVolSurface4(verboseCalibration)
+    
+    end = time.time()
+    
+    elapsed = end - start
+#    print("Elapsed Time:", elapsed)
+    testCases.compareTestCases()
