@@ -13,11 +13,11 @@ from financepy.finutils.FinDate import FinDate
 from financepy.finutils.FinDayCount import FinDayCountTypes
 from financepy.finutils.FinFrequency import FinFrequencyTypes
 from financepy.finutils.FinCalendar import FinCalendarTypes
-from financepy.products.funding.FinIborSingleCurve import FinIborSingleCurve
-from financepy.products.funding.FinIborFRA import FinIborFRA
-from financepy.products.funding.FinIborFuture import FinIborFuture
-from financepy.products.funding.FinIborDeposit import FinIborDeposit
-from financepy.products.funding.FinIborSwap import FinIborSwap
+from financepy.products.rates.FinIborSingleCurve import FinIborSingleCurve
+from financepy.products.rates.FinIborFRA import FinIborFRA
+from financepy.products.rates.FinIborFuture import FinIborFuture
+from financepy.products.rates.FinIborDeposit import FinIborDeposit
+from financepy.products.rates.FinIborSwap import FinIborSwap
 from financepy.finutils.FinCalendar import FinBusDayAdjustTypes
 from financepy.market.curves.FinInterpolator import FinInterpTypes
 from financepy.finutils.FinMath import ONE_MILLION
@@ -409,7 +409,7 @@ def test_FinIborDepositsFuturesSwaps():
     principal = 0.0
     floatSpread = 0.0
     floatDCCType = FinDayCountTypes.ACT_360
-    calendarType = FinCalendarTypes.US
+    calendarType = FinCalendarTypes.UNITED_STATES
     busDayAdjustRule = FinBusDayAdjustTypes.PRECEDING
 
     swapRate = 0.02776305
