@@ -7,10 +7,10 @@ import numpy as np
 sys.path.append("..")
 
 from financepy.finutils.FinMath import ONE_MILLION
-from financepy.products.funding.FinIborSingleCurve import FinIborSingleCurve
-from financepy.products.funding.FinIborSwap import FinIborSwap
-from financepy.products.funding.FinIborFRA import FinIborFRA
-from financepy.products.funding.FinIborDeposit import FinIborDeposit
+from financepy.products.rates.FinIborSingleCurve import FinIborSingleCurve
+from financepy.products.rates.FinIborSwap import FinIborSwap
+from financepy.products.rates.FinIborFRA import FinIborFRA
+from financepy.products.rates.FinIborDeposit import FinIborDeposit
 from financepy.finutils.FinCalendar import FinBusDayAdjustTypes
 from financepy.finutils.FinCalendar import FinDateGenRuleTypes
 from financepy.finutils.FinCalendar import FinCalendarTypes
