@@ -2,15 +2,14 @@
 # Copyright (C) 2018, 2019, 2020 Dominic O'Kane
 ###############################################################################
 
-from FinTestCases import FinTestCases, globalTestCaseMode
-
 import numpy as np
+import sys
+sys.path.append("..")
+
 from financepy.market.volatility.FinEquityVolCurve import FinEquityVolCurve
 from financepy.finutils.FinDate import FinDate
 
-import sys
-sys.path.append("..//..")
-
+from FinTestCases import FinTestCases, globalTestCaseMode
 testCases = FinTestCases(__file__, globalTestCaseMode)
 
 PLOT_GRAPHS = False
